@@ -9,9 +9,13 @@ class History(Command):
     """
 
     def run(self) -> int:
+        prev_count: int | None = None
+        self.print('date       time           res   old  fix  new   commit')
         for commit in get_commits(self.config.baseline_path):
+            commit.fix_lines_count(prev_count)
             count_formatted = f'{commit.lines_count:>3}'
             line = f'{commit.created_at} {self.colors.blue(count_formatted)}'
+            line += f' = {prev_count or 0:>3}'
             if commit.deletions:
                 formatted = f'{-commit.deletions: >+4}'
                 line += f' {self.colors.green(formatted)}'
@@ -20,5 +24,9 @@ class History(Command):
             if commit.insertions:
                 formatted = f'{commit.insertions: >+4}'
                 line += f' {self.colors.red(formatted)}'
+            else:
+                line += ' ' * 5
+            line += f'   {commit.hash}'
             self.print(line)
+            prev_count = commit.lines_count
         return 0
